<?php

declare(strict_types=1);

namespace App\Dictionary\PushMessage;

use App\Dictionary\WeChat\Official\OpenApi;

/**
 * 推送微信消息类型
 */
enum Type: int
{
    case OFFICIAL_TEMPLATE = 1;

    case OFFICIAL_SINGLE_SUBSCRIBE = 2;

    case OFFICIAL_SUBSCRIBE = 3;

    case OFFICIAL_CUSTOM = 4;

    /**
     * Label string.
     *
     * @return string
     */
    public function label(): string
    {
        return match ($this) {
            self::OFFICIAL_TEMPLATE => '公众号模板消息',
            self::OFFICIAL_SINGLE_SUBSCRIBE => '公众号一次性订阅消息',
            self::OFFICIAL_SUBSCRIBE => '公众号订阅消息',
            self::OFFICIAL_CUSTOM => '公众号客服消息',
        };
    }

    /**
     * Get Open Api.
     *
     * @return OpenApi
     */
    public function api(): OpenApi
    {
        return match ($this) {
            self::OFFICIAL_TEMPLATE => OpenApi::SEND_TEMPLATE_MESSAGE,
            self::OFFICIAL_SINGLE_SUBSCRIBE => OpenApi::SEND_SINGLE_SUBSCRIBE_MESSAGE,
            self::OFFICIAL_SUBSCRIBE => OpenApi::SEND_SUBSCRIBE_MESSAGE,
            self::OFFICIAL_CUSTOM => OpenApi::SEND_CUSTOM_MESSAGE,
        };
    }
}
