<?php

declare(strict_types=1);

namespace UnifyPayment\Cores\Struct;

use InvalidArgumentException;
use UnifyPayment\Cores\Traits\Arrayable;

/**
 * Struct Channels.
 */
class Channels
{
    use Arrayable;

    /**
     * @var string
     */
    public string $merchantId;

    /**
     * @var string
     */
    public string $secret;

    /**
     * @var string
     */
    public string $operatorId;

    /**
     * @var string
     */
    public string $channelId;

    /**
     * Channels Construct.
     *
     * @param string $merchantId
     * @param string $secret
     * @param string $operatorId
     * @param string $channelId
     */
    public function __construct(
        string $merchantId = '',
        string $secret = '',
        string $operatorId = '',
        string $channelId = ''
    ) {
        $this->setMerchantId($merchantId)
            ->setSecret($secret)
            ->setOperatorId($operatorId)
            ->setChannelId($channelId);
    }

    /**
     * Get merchantId value
     *
     * @return string|null
     */
    public function getMerchantId(): string
    {
        return $this->merchantId;
    }

    /**
     * Set merchantId value
     *
     * @param string $merchantId
     *
     * @return Channels
     */
    public function setMerchantId(string $merchantId = ''): Channels
    {
        // validation for constraint: string
        if (!is_string($merchantId)) {
            throw new InvalidArgumentException(
                sprintf(
                    'Invalid value %s, please provide a string, %s given',
                    var_export($merchantId, true),
                    gettype($merchantId)
                ), __LINE__
            );
        }

        $this->merchantId = $merchantId;
        return $this;
    }

    /**
     * Get secret value
     *
     * @return string
     */
    public function getSecret(): ?string
    {
        return $this->secret;
    }

    /**
     * Set secret value
     *
     * @param string $secret
     *
     * @return Channels
     */
    public function setSecret(string $secret = ''): Channels
    {
        // validation for constraint: string
        if (!is_string($secret)) {
            throw new InvalidArgumentException(
                sprintf(
                    'Invalid value %s, please provide a string, %s given',
                    var_export($secret, true),
                    gettype($secret)
                ), __LINE__
            );
        }

        $this->secret = $secret;
        return $this;
    }

    /**
     * Get operatorId value
     *
     * @return string
     */
    public function getOperatorId(): ?string
    {
        return $this->operatorId;
    }

    /**
     * Set operatorId value
     *
     * @param string $operatorId
     *
     * @return Channels
     */
    public function setOperatorId(string $operatorId = ''): Channels
    {
        // validation for constraint: string
        if (!is_string($operatorId)) {
            throw new InvalidArgumentException(
                sprintf(
                    'Invalid value %s, please provide a string, %s given',
                    var_export($operatorId, true),
                    gettype($operatorId)
                ), __LINE__
            );
        }

        $this->operatorId = $operatorId;
        return $this;
    }

    /**
     * Get channelId value
     *
     * @return string
     */
    public function getChannelId(): string
    {
        return $this->channelId;
    }

    /**
     * Set channelId value
     *
     * @param string $channelId
     *
     * @return Channels
     */
    public function setChannelId(string $channelId = ''): Channels
    {
        // validation for constraint: string
        if (!is_string($channelId)) {
            throw new InvalidArgumentException(
                sprintf(
                    'Invalid value %s, please provide a string, %s given',
                    var_export($channelId, true),
                    gettype($channelId)
                ), __LINE__
            );
        }

        $this->channelId = $channelId;
        return $this;
    }
}