<?php

declare(strict_types=1);

namespace UnifyPayment\Cores\Struct;

use InvalidArgumentException;
use UnifyPayment\Cores\Traits\Arrayable;

/**
 * Struct RefundOrder.
 */
class RefundOrder
{
    use Arrayable;

    /**
     * @var string
     */
    public string $orderNo;

    /**
     * @var string
     */
    public string $refundNo;

    /**
     * @var string
     */
    public string $refundAmount;

    /**
     * @var string
     */
    public string $refundReason;

    /**
     * RefundOrder construct.
     *
     * @param string $orderNo
     * @param string $refundNo
     * @param string $refundAmount
     * @param string $refundReason
     */
    public function __construct(
        string $orderNo = '',
        string $refundNo = '',
        string $refundAmount = '0',
        string $refundReason = ''
    ) {
        $this->setOrderNo($orderNo)
            ->setRefundNo($refundNo)
            ->setRefundAmount($refundAmount)
            ->setRefundReason($refundReason);
    }

    /**
     * Get orderNo value
     *
     * @return string|null
     */
    public function getOrderNo(): string
    {
        return $this->orderNo;
    }

    /**
     * Set orderNo value
     *
     * @param string $orderNo
     *
     * @return RefundOrder
     */
    public function setOrderNo(string $orderNo = ''): RefundOrder
    {
        // validation for constraint: string
        if (!is_string($orderNo)) {
            throw new InvalidArgumentException(
                sprintf(
                    'Invalid value %s, please provide a string, %s given',
                    var_export($orderNo, true),
                    gettype($orderNo)
                ), __LINE__
            );
        }

        $this->orderNo = $orderNo;
        return $this;
    }

    /**
     * Get refundNo value
     *
     * @return string|null
     */
    public function getRefundNo(): string
    {
        return $this->refundNo;
    }

    /**
     * Set refundNo value
     *
     * @param string $refundNo
     *
     * @return RefundOrder
     */
    public function setRefundNo(string $refundNo = ''): RefundOrder
    {
        // validation for constraint: string
        if (!is_string($refundNo)) {
            throw new InvalidArgumentException(
                sprintf(
                    'Invalid value %s, please provide a string, %s given',
                    var_export($refundNo, true),
                    gettype($refundNo)
                ), __LINE__
            );
        }

        $this->refundNo = $refundNo;
        return $this;
    }

    /**
     * Get refundAmount value
     *
     * @return string|null
     */
    public function getRefundAmount(): string
    {
        return $this->refundAmount;
    }

    /**
     * Set refundAmount value
     *
     * @param string $refundAmount
     *
     * @return RefundOrder
     */
    public function setRefundAmount(string $refundAmount = '0'): RefundOrder
    {
        // validation for constraint: float
        if (!is_string($refundAmount)) {
            throw new InvalidArgumentException(
                sprintf(
                    'Invalid value %s, please provide a string, %s given',
                    var_export($refundAmount, true),
                    gettype($refundAmount)
                ), __LINE__
            );
        }

        $this->refundAmount = $refundAmount;
        return $this;
    }

    /**
     * Get refundReason value
     *
     * @return string|null
     */
    public function getRefundReason(): string
    {
        return $this->refundReason;
    }

    /**
     * Set refundReason value
     *
     * @param string $refundReason
     *
     * @return RefundOrder
     */
    public function setRefundReason(string $refundReason = ''): RefundOrder
    {
        // validation for constraint: string
        if (!is_string($refundReason)) {
            throw new InvalidArgumentException(
                sprintf(
                    'Invalid value %s, please provide a string, %s given',
                    var_export($refundReason, true),
                    gettype($refundReason)
                ), __LINE__
            );
        }

        $this->refundReason = $refundReason;
        return $this;
    }
}