<?php

declare(strict_types=1);

namespace UnifyPayment\Mock;

use Faker\Factory;
use Faker\Generator;
use GuzzleHttp\Psr7\Response;

abstract class ResponseHandler extends Response
{

    const SUCCESS_CODE = 200;

    const FAILURE_CODE = 500;

    const JSON_HEADER = ['Content-Type' => 'application/json'];

    /**
     * 交易状态
     */
    const TRADE_STATE = [
        'SUCCESS',
        'REFUND',
        'NOTPAY',
        'CLOSED',
        'REVOKED',
        'USERPAYING',
        'PAYERROR'
    ];

    /**
     * 交易状态描述
     */
    const TRADE_STATE_DESC = [
        'SUCCESS' => '支付成功',
        'REFUND' => '转入退款',
        'NOTPAY' => '未支付',
        'CLOSED' => '已关闭',
        'REVOKED' => '已撤销',
        'USERPAYING' => '用户支付中',
        'PAYERROR' => '支付失败'
    ];

    /**
     * Faker.
     *
     * @var Generator
     */
    protected Generator $faker;

    /**
     * Response Construct.
     *
     * @param bool $successful
     */
    public function __construct(bool $successful)
    {
        $this->faker = Factory::create();

        if ($successful) {
            $resData = $this->success();
        } else {
            $resData = $this->failure();
        }

        parent::__construct(... $resData);
    }

    /**
     *
     * @param string $msg
     *
     * @return array
     */
    protected function getSuccessHeaderData(string $msg): array
    {
        return [
            'status' => self::SUCCESS_CODE,
            'tag' => 'SUCCESS',
            'success' => true,
            'msg' => 'msg',
            'response' => null
        ];
    }

    /**
     *
     * @param string $msg
     *
     * @return array
     */
    protected function getFailureHeaderData(string $msg): array
    {
        return [
            'status' => self::FAILURE_CODE,
            'tag' => 'FAILURE',
            'success' => false,
            'msg' => 'msg',
            'response' => null
        ];
    }

    /**
     * Success Response.
     *
     * @return mixed
     */
    abstract public function success();

    /**
     * Fail Response.
     *
     * @return mixed
     */
    abstract public function failure();
}